@@ -4,7 +4,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <fstream.h>
+/* #include <fstream.h> */
 
 #include "globals.h"
 
